% Esta funcion estandariza el problema inverso
%
% Sintaxis:
%           [Ui,si,Vis,R,ord,w,Vi]=stdbc(K,L,RefProm)
% Donde:
%        K - Matriz del leadfield.
%        L - Laplaciano.
%        RefProm - Referencia Promedio
%
% Para mas informacion ver Readme.doc. 
%
% Autor: Nelson J. Trujillo Barreto.

function [Ui,si,Vis,R,ord,w,Vi]=stdbc(K,L,RefProm)
[ne,nggl]=size(K);

if RefProm
 H = eye(ne) - ones(ne,ne)/ne;
 K = H*K;
end

%Lr=L(1:3:nggl,1:3:nggl);
if L(1,1)<0 ;  L=-L; end;
[R,ord]=lchol(L);
clear L

w = wiiv(K,1);
K = klinvr(R,K',ord,w);

[Ui,si,Vi] = svdrapid(K);

Vis = ljinvl(R,Vi,ord,w);
